Blob Blame History Raw
diff --git a/docs/api/xmlstream/tostring.rst b/docs/api/xmlstream/tostring.rst
index 68abbdb638136c0e004a766cfb8e9a71c9392fd8..107e97b0d2b9c6cba7452f7533c6447cfec61bd9 100644
--- a/docs/api/xmlstream/tostring.rst
+++ b/docs/api/xmlstream/tostring.rst
@@ -13,7 +13,7 @@ hides namespaces when able and does not introduce excessive namespace
 prefixes::
 
     >>> from slixmpp.xmlstream.tostring import tostring
-    >>> from xml.etree import cElementTree as ET
+    >>> from xml.etree import ElementTree as ET
     >>> xml = ET.fromstring('<foo xmlns="bar"><baz /></foo>')
     >>> ET.tostring(xml)
     '<ns0:foo xmlns:ns0="bar"><ns0:baz /></foo>'
diff --git a/slixmpp/plugins/xep_0009/stanza/RPC.py b/slixmpp/plugins/xep_0009/stanza/RPC.py
index f8cec481d031ef188b2a878eb988b7217b79056e..542c839c5e54f288c77b03aa180b5faff1e60383 100644
--- a/slixmpp/plugins/xep_0009/stanza/RPC.py
+++ b/slixmpp/plugins/xep_0009/stanza/RPC.py
@@ -7,7 +7,7 @@
 """
 
 from slixmpp.xmlstream.stanzabase import ElementBase
-from xml.etree import cElementTree as ET
+from xml.etree import ElementTree as ET
 
 
 class RPCQuery(ElementBase):
diff --git a/slixmpp/xmlstream/stanzabase.py b/slixmpp/xmlstream/stanzabase.py
index 3e45f613d37e65bb06542334c3ba4740ffd7926c..c3dbfb6770e2cd9b505af299410afffe243e0aa5 100644
--- a/slixmpp/xmlstream/stanzabase.py
+++ b/slixmpp/xmlstream/stanzabase.py
@@ -17,7 +17,7 @@ from __future__ import with_statement, unicode_literals
 import copy
 import logging
 import weakref
-from xml.etree import cElementTree as ET
+from xml.etree import ElementTree as ET
 
 from slixmpp.xmlstream import JID
 from slixmpp.xmlstream.tostring import tostring
@@ -203,7 +203,7 @@ class ElementBase(object):
 
     """
     The core of Slixmpp's stanza XML manipulation and handling is provided
     by ElementBase. ElementBase wraps XML cElementTree objects and enables
     access to the XML contents through dictionary syntax, similar in style
     to the Ruby XMPP library Blather's stanza implementation.
 
@@ -387,7 +387,7 @@ class ElementBase(object):
         self._index = 0
 
         #: The underlying XML object for the stanza. It is a standard
-        #: :class:`xml.etree.cElementTree` object.
+        #: :class:`xml.etree.ElementTree` object.
         self.xml = xml
 
         #: An ordered dictionary of plugin stanzas, mapped by their
@@ -203,7 +203,7 @@ class ElementBase(object):
     """
     The core of Slixmpp's stanza XML manipulation and handling is provided
-    by ElementBase. ElementBase wraps XML cElementTree objects and enables
+    by ElementBase. ElementBase wraps XML ElementTree objects and enables
     access to the XML contents through dictionary syntax, similar in style
     to the Ruby XMPP library Blather's stanza implementation.